package com.ansis.remoting.sample.eclipse.client.actions;

import java.util.Properties;

import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;

import com.ansis.remoting.sample.ejb.Session1Remote;
import com.ansis.remoting.sample.ejb.Session2Remote;

/**
 * Our sample action implements workbench action delegate.
 * The action proxy will be created by the workbench and
 * shown in the UI. When the user tries to use the action,
 * this delegate will be created and execution will be 
 * delegated to it.
 * @see IWorkbenchWindowActionDelegate
 */
@SuppressWarnings("nls")
public class SampleAction implements IWorkbenchWindowActionDelegate {
	
	private IWorkbenchWindow window;
	/**
	 * The constructor.
	 */
	public SampleAction() {
	}

	/**
	 * The action has been activated. The argument of the
	 * method represents the 'real' action sitting
	 * in the workbench UI.
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	public void run(final IAction action) {
		
		final String response = lookupBothBeans();
		MessageDialog.openInformation(
			window.getShell(),
			"Test Eclipse Plugin",
			"Hello, Eclipse world: " + response);
	}

	private String lookupBothBeans() {
		
		final Properties props = new Properties(); 
	    props.setProperty("java.naming.factory.initial", "com.sun.enterprise.naming.SerialInitContextFactory");
	    props.setProperty("java.naming.factory.url.pkgs", "com.sun.enterprise.naming"); 
	    props.setProperty("java.naming.factory.state", "com.sun.corba.ee.impl.presentation.rmi.JNDIStateFactoryImpl"); 
	    
	    props.setProperty("org.omg.CORBA.ORBInitialHost", "localhost"); 
	    props.setProperty("org.omg.CORBA.ORBInitialPort", "24037"); 
	    
	    try {
			final InitialContext context = new InitialContext(props);
			
			final Session1Remote bean1 = (Session1Remote) context.lookup("java:global/com.ansis.remoting.sample/com_ansis_remoting_sample_ejb/SessionBean1");
			final Session2Remote bean2 = (Session2Remote) context.lookup("java:global/com.ansis.remoting.sample/com_ansis_remoting_sample_ejb/SessionBean2");
			
			return bean2.helloWorld();
		} catch (final NamingException e) {
			e.printStackTrace();
			return "Error";
		}
	}

	/**
	 * Selection in the workbench has been changed. We 
	 * can change the state of the 'real' action here
	 * if we want, but this can only happen after 
	 * the delegate has been created.
	 * @see IWorkbenchWindowActionDelegate#selectionChanged
	 */
	public void selectionChanged(final IAction action, final ISelection selection) {
	}

	/**
	 * We can use this method to dispose of any system
	 * resources we previously allocated.
	 * @see IWorkbenchWindowActionDelegate#dispose
	 */
	public void dispose() {
	}

	/**
	 * We will cache window object in order to
	 * be able to provide parent shell for the message dialog.
	 * @see IWorkbenchWindowActionDelegate#init
	 */
	public void init(final IWorkbenchWindow window) {
		this.window = window;
	}
}